# xlc

Internationalization(i18n) and Localization(l10n) of Multiple Languages

- [pycountry](https://github.com/flyingcircusio/pycountry)

## Standardization

Please refer to the following standards:

- ISO 639 Codes for the representation of names of languages
  - ISO 639-3 Codes for the representation of names of languages — Part 3: Alpha-3 code for comprehensive coverage of languages
  - ISO 639-5 Codes for the representation of names of languages — Part 5: Alpha-3 code for language families and groups
- ISO 3166 Codes for the representation of names of countries and their subdivisions
  - ISO 3166-1 Codes for the representation of names of countries and their subdivisions — Part 1: Country code
  - ISO 3166-2 Codes for the representation of names of countries and their subdivisions — Part 2: Country subdivision code
  - ISO 3166-3 Codes for the representation of names of countries and their subdivisions — Part 3: Code for formerly used names of countries
- ISO 4217 Codes for the representation of currencies
- ISO 15924 Information and documentation — Codes for the representation of names of scripts

## reference

- [language-subtag-registry](https://www.iana.org/assignments/language-subtag-registry/language-subtag-registry)
- [ms-lcid](https://learn.microsoft.com/en-us/openspecs/windows_protocols/ms-lcid/)
